@@ -103,19 +103,23 @@ Rating::Rating(const QVariantMap &data)
          data.value(QStringLiteral("ratings_total")).toULongLong(), data.value(QStringLiteral("ratings_average")).toDouble() * 2, data.value(QStringLiteral("histogram")).toString());
 }
 
-Rating::Rating(const QString& packageName, int ratingCount, int rating, const QString& histogram)
+Rating::Rating(const QString& packageName, quint64 ratingCount, int rating, const QString& histogram)
     : QObject()
 {
     init(packageName, ratingCount, rating, histogram);
 }
 
-Rating::Rating(const QString& packageName, QStringList histogram)
+Rating::Rating(const QString& packageName, int inst, int /*vote*/, int /*old*/, int /*recent*/)
     : QObject()
+    , m_packageName(packageName)
+    , m_ratingCount(inst)
+    , m_rating(0)
+    , m_ratingPoints(0)
+    , m_sortableRating(m_rating)
 {
-    debInit(packageName,histogram);
 }
 
-void Rating::init(const QString& packageName, int ratingCount, int rating, const QString& histogram)
+void Rating::init(const QString& packageName, quint64 ratingCount, int rating, const QString& histogram)
 {
     m_packageName = packageName;
     m_ratingCount = ratingCount;
@@ -123,7 +127,7 @@ void Rating::init(const QString& packageName, int ratingCount, int rating, const
     m_ratingPoints = 0;
     m_sortableRating = 0;
 
-    QStringList histo = histogram.mid(1,histogram.size()-2).split(QStringLiteral(", "));
+    auto histo = histogram.midRef(1,histogram.size()-2).split(QStringLiteral(", "));
     QVector<int> spread = QVector<int>();
 
     for(int i=0; i<histo.size(); ++i) {
@@ -135,35 +139,6 @@ void Rating::init(const QString& packageName, int ratingCount, int rating, const
     m_sortableRating = dampenedRating(spread) * 2;
 }
 
-void Rating::debInit(const QString& packageName, QStringList histogram)
-{
-    int installed = 0;
-    m_packageName = packageName;
-    m_sortableRating = 0;
-    //inst, vote, old, recent, no-files
-    QVector<int> values = QVector<int>();
-    histogram.removeDuplicates();
-    for(int i=1; i<histogram.count(); ++i) {
-        int points = histogram[i].toInt();
-        installed+=points;
-        values.append(points);
-    }
-    m_sortableRating = values[0];
-    m_ratingCount = installed;
-
-    if (installed) {
-        m_rating = values[0]/(m_ratingCount*1.0)*10;
-    } else {
-        m_rating = 0;
-    }
-
-    if (values[0]-values[1]) {
-        m_ratingPoints = (values[2]*1.0)/(values[0]-values[1]);
-    } else {
-        m_ratingPoints = 0;
-    }
-}
-
 Rating::~Rating()
 {
 }
