@@ -55,6 +55,7 @@ ResourcesModel::ResourcesModel(QObject* parent, bool load)
         { StateRole, "state" },
         { RatingRole, "rating" },
         { RatingPointsRole, "ratingPoints" },
+        { RatingCountRole, "ratingCount" },
         { SortableRatingRole, "sortableRating" },
         { ActiveRole, "active" },
         { InstalledRole, "isInstalled" },
@@ -176,7 +177,7 @@ QVariant ResourcesModel::data(const QModelIndex& index, int role) const
         return QVariant();
     }
 
-    AbstractResource* resource = resourceAt(index.row());
+    AbstractResource* const resource = resourceAt(index.row());
     switch(role) {
         case ActiveRole:
             return TransactionModel::global()->transactionFromResource(resource) != nullptr;
@@ -184,9 +185,17 @@ QVariant ResourcesModel::data(const QModelIndex& index, int role) const
             return qVariantFromValue<QObject*>(resource);
         case RatingPointsRole:
         case RatingRole:
+        case RatingCountRole:
         case SortableRatingRole: {
-            Rating* rating = resource->rating();
-            return rating ? rating->property(roleNames().value(role).constData()) : -1;
+            Rating* const rating = resource->rating();
+            if (rating)
+                return rating->property(roleNames().value(role).constData());
+            else {
+                const int idx = Rating::staticMetaObject.indexOfProperty(roleNames().value(role).constData());
+                QVariant val = QVariant(0);
+                val.convert(Rating::staticMetaObject.property(idx).type());
+                return val;
+            }
         }
         case Qt::DecorationRole:
         case Qt::DisplayRole:
@@ -403,6 +412,9 @@ void ResourcesModel::integrateActions(KActionCollection* w)
 
 void ResourcesModel::resourceChangedByTransaction(Transaction* t)
 {
+    if (!t->resource())
+        return;
+
     Q_ASSERT(!t->resource()->backend()->isFetching());
     QModelIndex idx = resourceIndex(t->resource());
     if(idx.isValid())
